@@ -100,14 +100,13 @@ sub to_js ( $self ) {
         my $method = "EXT_$self->{ctx}->{generator}";
 
         my $l10n = sub ( $msgid, $msgid_plural = undef, $num = undef ) : prototype($;$$) {
-            my $domain = caller;
 
-            # register l10n domain
-            $self->{ctx}->{l10n_domain}->{$domain} = undef;
+            # register msgid in ctx
+            $self->{ctx}->{l10n}->{$msgid} = 1;
 
             return bless {
                 ctx => $self,
-                buf => [ [ $domain, $msgid, $msgid_plural, $num // 1 ] ],
+                buf => [ [ $msgid, $msgid_plural, $num // 1 ] ],
               },
               'Pcore::Ext::Context::L10N';
         };
@@ -205,14 +204,13 @@ package Pcore::Ext::Context::_l10n {
     }
 
     sub FETCH {
-        my $domain = caller;
 
-        # register l10n domain
-        $_[0]->[0]->{ctx}->{l10n_domain}->{$domain} = undef;
+        # register msgid in ctx
+        $_[0]->[0]->{ctx}->{l10n}->{ $_[1] } = 1;
 
         return bless {
             ctx => $_[0]->[0],
-            buf => [ [ $domain, $_[1] ] ],
+            buf => [ [ $_[1] ] ],
           },
           'Pcore::Ext::Context::L10N';
     }
@@ -230,7 +228,7 @@ package Pcore::Ext::Context::_l10n {
 ## |      | 47                   | * Private subroutine/method '_ext_class' declared but not used                                                 |
 ## |      | 60                   | * Private subroutine/method '_ext_type' declared but not used                                                  |
 ## |------+----------------------+----------------------------------------------------------------------------------------------------------------|
-## |    2 | 136, 137, 138, 146   | Miscellanea::ProhibitTies - Tied variable used                                                                 |
+## |    2 | 135, 136, 137, 145   | Miscellanea::ProhibitTies - Tied variable used                                                                 |
 ## +------+----------------------+----------------------------------------------------------------------------------------------------------------+
 ##
 ## -----SOURCE FILTER LOG END-----
